import json
from typing import Dict, List, Optional

import numpy as np
import requests
from fasttext.FastText import _FastText

from sziszapangma.core.transformer.embedding_transformer import EmbeddingTransformer
import fasttext.util


class FasttextEmbeddingTransformer(EmbeddingTransformer):
    _lang_id: str
    _model: _FastText

    def __init__(self, lang_id: str):
        self._lang_id = lang_id
        fasttext.util.download_model(lang_id, if_exists='ignore')
        self._model = fasttext.load_model(f'cc.{lang_id}.300.bin')

    def get_embedding(self, word: str) -> np.ndarray:
        return self._model.get_word_vector(word)

    def get_embeddings(self, words: List[str]) -> Dict[str, np.ndarray]:
        return {it: self.get_embedding(it) for it in words}
